ConfigurationResult

Enum ConfigurationResult 

pub enum ConfigurationResult {
    SyncSucceeded,
    MissingConfigurationForBackend,
    NoAvailableBackendConnection,
    ProvisionedBackendsButNoAdminCreds,
    NotAllConnectionsAvailableAndNoAdminCreds,
}
The possible result of a Signstar host configuration.

Note

The variants of this enum are not considered run-time errors.

Variants



SyncSucceeded

The synchronization of the host’s configuration with its system users and backends succeeded.



MissingConfigurationForBackend

There is no configuration section for a particular type of HSM backend.



NoAvailableBackendConnection

There are no connections available for a particular type of HSM backend.

Note

This may indicate a transient network issue, or USB hardware failure.



ProvisionedBackendsButNoAdminCreds

There are provisioned backends, but no administrative credentials.

Note

This likely indicates, that a backup and administrative credentials need to be provided to the system to restore from the backup.



NotAllConnectionsAvailableAndNoAdminCreds

Not all connections of a particular type of HSM backend are present and there are no administrative credentials.

Note

This may indicate a transient network issue, or USB hardware failure. Only with all configured connections available, the system can consider creating (new) administrative credentials.