HostConfiguration

Struct HostConfiguration 

pub struct HostConfiguration<'config> {
    config: &'config Config,
}
Signstar host configuration.

Manages the synchronization of HSM backends with the Signstar configuration, as well as the configuration of non-administrative users and their credentials for their respective backends.

Fields

config: &'config Config

The Signstar configuration.

Implementations

Source

impl<'config> HostConfiguration<'config>

pub fn sync(&self) -> Result<ConfigurationResult, Error>

Syncs the Signstar host with its configuration.

Errors

Returns an error, if

  • the syncing of NetHSM backends fails
  • the syncing of YubiHSM2 backends fails
Source

impl<'config> HostConfiguration<'config>

pub fn new(config: &'config Config) -> Self

Creates a new HostConfiguration from a Config.

pub fn config(&self) -> &Config

Returns a reference to the Config.

Source

impl<'config> HostConfiguration<'config>

fn load_nethsm_admin_credentials(&self) -> Result<NetHsmAdminCredentials, Error>

Loads NetHsmAdminCredentials.

Errors

Returns an error if NetHsmAdminCredentials::load fails.

fn available_nethsm_connections(config: &NetHsmConfig) -> Vec<NetHsm>

Returns the list of available connections to NetHSM backends.

fn provisioned_nethsm_connections(config: &NetHsmConfig) -> Vec<&Connection>

Returns the list of provisioned NetHSM backend connections.

fn create_nethsm_non_admin_credentials( &self, ) -> Result<Vec<FullCredentials>, Error>

Creates new credentials for all non-administrative NetHSM backend users.

Errors

Returns an error, if the non-administrative credentials for a specific user cannot be created.

fn sync_nethsm_backends( &self, available_connections: Vec<NetHsm>, admin_credentials: &NetHsmAdminCredentials, user_credentials: &[FullCredentials], ) -> Result<(), Error>

Syncs all available NetHSM backends.

Returns early success, if there is no NetHSM section in the Signstar config.

Errors

Returns an error, if

pub fn sync_nethsm(&self) -> Result<ConfigurationResult, Error>

Syncs the states of all available NetHSM backends with that of the Signstar configuration.

Errors

Returns an error, if

  • the creation of non-administrative credentials fails
  • the syncing of the backend fails
Source

impl<'config> HostConfiguration<'config>

fn load_yubihsm2_admin_credentials( &self, ) -> Result<YubiHsm2AdminCredentials, Error>

Loads YubiHsm2AdminCredentials.

Errors

Returns an error if YubiHsm2AdminCredentials::load fails.

fn create_yubihsm2_non_admin_credentials( &self, ) -> Result<Vec<Credentials>, Error>

Creates new credentials for all non-administrative YubiHSM2 backend users.

Errors

Returns an error, if the non-administrative credentials for a specific user cannot be created.

fn available_yubihsm2_connections(config: &YubiHsm2Config) -> Vec<Connector>

Returns the list of available connections to YubiHSM2 backends.

fn provisioned_yubihsm2_connections(config: &YubiHsm2Config) -> Vec<&Connection>

Returns the list of provisioned YubiHSM2 backend connections.

fn sync_yubihsm2_backends( &self, available_connections: Vec<Connector>, admin_credentials: &YubiHsm2AdminCredentials, user_credentials: &[Credentials], ) -> Result<(), Error>

Syncs all available YubiHSM2 backends.

Returns early success, if there is no YubiHSM2 section in the Signstar config.

Errors

Returns an error, if

pub fn sync_yubihsm2(&self) -> Result<ConfigurationResult, Error>

Syncs the states of all available YubiHSM2 backends with that of the Signstar configuration.

Errors

Returns an error, if

  • the creation of non-administrative credentials fails
  • the syncing of the backend fails