pub struct HostConfiguration<'config> {
config: &'config Config,
}Expand description
Signstar host configuration.
Manages the synchronization of HSM backends with the Signstar configuration, as well as the configuration of non-administrative users and their credentials for their respective backends.
Fields
config: &'config ConfigThe Signstar configuration.
Implementations
Sourceimpl<'config> HostConfiguration<'config>
impl<'config> HostConfiguration<'config>
Sourceimpl<'config> HostConfiguration<'config>
impl<'config> HostConfiguration<'config>
Sourceimpl<'config> HostConfiguration<'config>
impl<'config> HostConfiguration<'config>
Sourcefn load_nethsm_admin_credentials(&self) -> Result<NetHsmAdminCredentials, Error>
fn load_nethsm_admin_credentials(&self) -> Result<NetHsmAdminCredentials, Error>
Sourcefn available_nethsm_connections(config: &NetHsmConfig) -> Vec<NetHsm>
fn available_nethsm_connections(config: &NetHsmConfig) -> Vec<NetHsm>
Returns the list of available connections to NetHSM backends.
Sourcefn provisioned_nethsm_connections(config: &NetHsmConfig) -> Vec<&Connection>
fn provisioned_nethsm_connections(config: &NetHsmConfig) -> Vec<&Connection>
Returns the list of provisioned NetHSM backend connections.
Sourcefn create_nethsm_non_admin_credentials(
&self,
) -> Result<Vec<FullCredentials>, Error>
fn create_nethsm_non_admin_credentials( &self, ) -> Result<Vec<FullCredentials>, Error>
Creates new credentials for all non-administrative NetHSM backend users.
Errors
Returns an error, if the non-administrative credentials for a specific user cannot be created.
Sourcefn sync_nethsm_backends(
&self,
available_connections: Vec<NetHsm>,
admin_credentials: &NetHsmAdminCredentials,
user_credentials: &[FullCredentials],
) -> Result<(), Error>
fn sync_nethsm_backends( &self, available_connections: Vec<NetHsm>, admin_credentials: &NetHsmAdminCredentials, user_credentials: &[FullCredentials], ) -> Result<(), Error>
Syncs all available NetHSM backends.
Returns early success, if there is no NetHSM section in the Signstar config.
Errors
Returns an error, if
NetHsmAdminCredentials::loadcannot load administrative credentials- a
NetHsmBackendcannot be created for a connection - running
NetHsmBackend::syncfor a specific backend fails
Sourcepub fn sync_nethsm(&self) -> Result<ConfigurationResult, Error>
pub fn sync_nethsm(&self) -> Result<ConfigurationResult, Error>
Syncs the states of all available NetHSM backends with that of the Signstar configuration.
Errors
Returns an error, if
- the creation of non-administrative credentials fails
- the syncing of the backend fails
Sourceimpl<'config> HostConfiguration<'config>
impl<'config> HostConfiguration<'config>
Sourcefn load_yubihsm2_admin_credentials(
&self,
) -> Result<YubiHsm2AdminCredentials, Error>
fn load_yubihsm2_admin_credentials( &self, ) -> Result<YubiHsm2AdminCredentials, Error>
Sourcefn create_yubihsm2_non_admin_credentials(
&self,
) -> Result<Vec<Credentials>, Error>
fn create_yubihsm2_non_admin_credentials( &self, ) -> Result<Vec<Credentials>, Error>
Creates new credentials for all non-administrative YubiHSM2 backend users.
Errors
Returns an error, if the non-administrative credentials for a specific user cannot be created.
Sourcefn available_yubihsm2_connections(config: &YubiHsm2Config) -> Vec<Connector>
fn available_yubihsm2_connections(config: &YubiHsm2Config) -> Vec<Connector>
Returns the list of available connections to YubiHSM2 backends.
Sourcefn provisioned_yubihsm2_connections(config: &YubiHsm2Config) -> Vec<&Connection>
fn provisioned_yubihsm2_connections(config: &YubiHsm2Config) -> Vec<&Connection>
Returns the list of provisioned YubiHSM2 backend connections.
Sourcefn sync_yubihsm2_backends(
&self,
available_connections: Vec<Connector>,
admin_credentials: &YubiHsm2AdminCredentials,
user_credentials: &[Credentials],
) -> Result<(), Error>
fn sync_yubihsm2_backends( &self, available_connections: Vec<Connector>, admin_credentials: &YubiHsm2AdminCredentials, user_credentials: &[Credentials], ) -> Result<(), Error>
Syncs all available YubiHSM2 backends.
Returns early success, if there is no YubiHSM2 section in the Signstar config.
Errors
Returns an error, if
YubiHsm2AdminCredentials::loadcannot load administrative credentials- a
YubiHsm2Backendcannot be created for a connection - running
YubiHsm2Backend::syncfor a specific backend fails
Sourcepub fn sync_yubihsm2(&self) -> Result<ConfigurationResult, Error>
pub fn sync_yubihsm2(&self) -> Result<ConfigurationResult, Error>
Syncs the states of all available YubiHSM2 backends with that of the Signstar configuration.
Errors
Returns an error, if
- the creation of non-administrative credentials fails
- the syncing of the backend fails